# mypy-boto3-medialive

[![PyPI - mypy-boto3-medialive](https://img.shields.io/pypi/v/mypy-boto3-medialive.svg?color=blue)](https://pypi.org/project/mypy-boto3-medialive)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-medialive.svg?color=blue)](https://pypi.org/project/mypy-boto3-medialive)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-medialive?color=blue)](https://pypistats.org/packages/mypy-boto3-medialive)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.MediaLive 1.17.65](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/medialive.html#MediaLive)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.10.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-medialive docs](https://github.com/vemel/mypy_boto3_builder/service_docs/mypy_boto3_medialive/README.md)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-medialive](#mypy-boto3-medialive)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `MediaLive` service.

```bash
python -m pip install boto3-stubs[medialive]
```

## Usage

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[medialive]` in your environment:
  `python -m pip install 'boto3-stubs[medialive]'`

Both type checking and auto-complete should work for `MediaLive` service. No
explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[medialive]` in your environment:
  `python -m pip install 'boto3-stubs[medialive]'`

Both type checking and auto-complete should work for `MediaLive` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[medialive]` in your environment:
  `python -m pip install 'boto3-stubs[medialive]'`
- Run `mypy` as usual

Type checking should work for `MediaLive` service. No explicit type annotations
required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[medialive]` in your environment:
  `python -m pip install 'boto3-stubs[medialive]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `MediaLive` service. No explicit type annotations
required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`MediaLiveClient` provides annotations for `boto3.client("medialive")`.

```python
import boto3

from mypy_boto3_medialive import MediaLiveClient

client: MediaLiveClient = boto3.client("medialive")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: MediaLiveClient = session.client("medialive")
```

### Paginators annotations

`mypy_boto3_medialive.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_medialive import MediaLiveClient
from mypy_boto3_medialive.paginator import (
    DescribeSchedulePaginator,
    ListChannelsPaginator,
    ListInputDeviceTransfersPaginator,
    ListInputDevicesPaginator,
    ListInputSecurityGroupsPaginator,
    ListInputsPaginator,
    ListMultiplexProgramsPaginator,
    ListMultiplexesPaginator,
    ListOfferingsPaginator,
    ListReservationsPaginator,
)

client: MediaLiveClient = boto3.client("medialive")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_schedule_paginator: DescribeSchedulePaginator = client.get_paginator("describe_schedule")
list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
list_input_device_transfers_paginator: ListInputDeviceTransfersPaginator = client.get_paginator("list_input_device_transfers")
list_input_devices_paginator: ListInputDevicesPaginator = client.get_paginator("list_input_devices")
list_input_security_groups_paginator: ListInputSecurityGroupsPaginator = client.get_paginator("list_input_security_groups")
list_inputs_paginator: ListInputsPaginator = client.get_paginator("list_inputs")
list_multiplex_programs_paginator: ListMultiplexProgramsPaginator = client.get_paginator("list_multiplex_programs")
list_multiplexes_paginator: ListMultiplexesPaginator = client.get_paginator("list_multiplexes")
list_offerings_paginator: ListOfferingsPaginator = client.get_paginator("list_offerings")
list_reservations_paginator: ListReservationsPaginator = client.get_paginator("list_reservations")
```

### Waiters annotations

`mypy_boto3_medialive.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_medialive import MediaLiveClient
from mypy_boto3_medialive.waiter import (
    ChannelCreatedWaiter,
    ChannelDeletedWaiter,
    ChannelRunningWaiter,
    ChannelStoppedWaiter,
    InputAttachedWaiter,
    InputDeletedWaiter,
    InputDetachedWaiter,
    MultiplexCreatedWaiter,
    MultiplexDeletedWaiter,
    MultiplexRunningWaiter,
    MultiplexStoppedWaiter,
)

client: MediaLiveClient = boto3.client("medialive")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
channel_created_waiter: ChannelCreatedWaiter = client.get_waiter("channel_created")
channel_deleted_waiter: ChannelDeletedWaiter = client.get_waiter("channel_deleted")
channel_running_waiter: ChannelRunningWaiter = client.get_waiter("channel_running")
channel_stopped_waiter: ChannelStoppedWaiter = client.get_waiter("channel_stopped")
input_attached_waiter: InputAttachedWaiter = client.get_waiter("input_attached")
input_deleted_waiter: InputDeletedWaiter = client.get_waiter("input_deleted")
input_detached_waiter: InputDetachedWaiter = client.get_waiter("input_detached")
multiplex_created_waiter: MultiplexCreatedWaiter = client.get_waiter("multiplex_created")
multiplex_deleted_waiter: MultiplexDeletedWaiter = client.get_waiter("multiplex_deleted")
multiplex_running_waiter: MultiplexRunningWaiter = client.get_waiter("multiplex_running")
multiplex_stopped_waiter: MultiplexStoppedWaiter = client.get_waiter("multiplex_stopped")
```

### Literals

`mypy_boto3_medialive.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_medialive.literals import (
    AacCodingMode,
    AacInputType,
    AacProfile,
    AacRateControlMode,
    AacRawFormat,
    AacSpec,
    AacVbrQuality,
    Ac3BitstreamMode,
    Ac3CodingMode,
    Ac3DrcProfile,
    Ac3LfeFilter,
    Ac3MetadataControl,
    AcceptHeader,
    AfdSignaling,
    AudioDescriptionAudioTypeControl,
    AudioDescriptionLanguageCodeControl,
    AudioLanguageSelectionPolicy,
    AudioNormalizationAlgorithm,
    AudioNormalizationAlgorithmControl,
    AudioOnlyHlsSegmentType,
    AudioOnlyHlsTrackType,
    AudioType,
    AuthenticationScheme,
    AvailBlankingState,
    BlackoutSlateNetworkEndBlackout,
    BlackoutSlateState,
    BurnInAlignment,
    BurnInBackgroundColor,
    BurnInFontColor,
    BurnInOutlineColor,
    BurnInShadowColor,
    BurnInTeletextGridControl,
    CdiInputResolution,
    ChannelClass,
    ChannelCreatedWaiterName,
    ChannelDeletedWaiterName,
    ChannelRunningWaiterName,
    ChannelState,
    ChannelStoppedWaiterName,
    ContentType,
    DescribeSchedulePaginatorName,
    DeviceSettingsSyncState,
    DeviceUpdateStatus,
    DvbSdtOutputSdt,
    DvbSubDestinationAlignment,
    DvbSubDestinationBackgroundColor,
    DvbSubDestinationFontColor,
    DvbSubDestinationOutlineColor,
    DvbSubDestinationShadowColor,
    DvbSubDestinationTeletextGridControl,
    Eac3AttenuationControl,
    Eac3BitstreamMode,
    Eac3CodingMode,
    Eac3DcFilter,
    Eac3DrcLine,
    Eac3DrcRf,
    Eac3LfeControl,
    Eac3LfeFilter,
    Eac3MetadataControl,
    Eac3PassthroughControl,
    Eac3PhaseControl,
    Eac3StereoDownmix,
    Eac3SurroundExMode,
    Eac3SurroundMode,
    EbuTtDDestinationStyleControl,
    EbuTtDFillLineGapControl,
    EmbeddedConvert608To708,
    EmbeddedScte20Detection,
    FeatureActivationsInputPrepareScheduleActions,
    FecOutputIncludeFec,
    FixedAfd,
    Fmp4NielsenId3Behavior,
    Fmp4TimedMetadataBehavior,
    FollowPoint,
    FrameCaptureIntervalUnit,
    GlobalConfigurationInputEndAction,
    GlobalConfigurationLowFramerateInputs,
    GlobalConfigurationOutputLockingMode,
    GlobalConfigurationOutputTimingSource,
    H264AdaptiveQuantization,
    H264ColorMetadata,
    H264EntropyEncoding,
    H264FlickerAq,
    H264ForceFieldPictures,
    H264FramerateControl,
    H264GopBReference,
    H264GopSizeUnits,
    H264Level,
    H264LookAheadRateControl,
    H264ParControl,
    H264Profile,
    H264QualityLevel,
    H264RateControlMode,
    H264ScanType,
    H264SceneChangeDetect,
    H264SpatialAq,
    H264SubGopLength,
    H264Syntax,
    H264TemporalAq,
    H264TimecodeInsertionBehavior,
    H265AdaptiveQuantization,
    H265AlternativeTransferFunction,
    H265ColorMetadata,
    H265FlickerAq,
    H265GopSizeUnits,
    H265Level,
    H265LookAheadRateControl,
    H265Profile,
    H265RateControlMode,
    H265ScanType,
    H265SceneChangeDetect,
    H265Tier,
    H265TimecodeInsertionBehavior,
    HlsAdMarkers,
    HlsAkamaiHttpTransferMode,
    HlsCaptionLanguageSetting,
    HlsClientCache,
    HlsCodecSpecification,
    HlsDirectoryStructure,
    HlsDiscontinuityTags,
    HlsEncryptionType,
    HlsH265PackagingType,
    HlsId3SegmentTaggingState,
    HlsIncompleteSegmentBehavior,
    HlsIvInManifest,
    HlsIvSource,
    HlsManifestCompression,
    HlsManifestDurationFormat,
    HlsMediaStoreStorageClass,
    HlsMode,
    HlsOutputSelection,
    HlsProgramDateTime,
    HlsRedundantManifest,
    HlsSegmentationMode,
    HlsStreamInfResolution,
    HlsTimedMetadataId3Frame,
    HlsTsFileMode,
    HlsWebdavHttpTransferMode,
    IFrameOnlyPlaylistType,
    InputAttachedWaiterName,
    InputClass,
    InputCodec,
    InputDeblockFilter,
    InputDeletedWaiterName,
    InputDenoiseFilter,
    InputDetachedWaiterName,
    InputDeviceActiveInput,
    InputDeviceConfiguredInput,
    InputDeviceConnectionState,
    InputDeviceIpScheme,
    InputDeviceScanType,
    InputDeviceState,
    InputDeviceTransferType,
    InputDeviceType,
    InputFilter,
    InputLossActionForHlsOut,
    InputLossActionForMsSmoothOut,
    InputLossActionForRtmpOut,
    InputLossActionForUdpOut,
    InputLossImageType,
    InputMaximumBitrate,
    InputPreference,
    InputResolution,
    InputSecurityGroupState,
    InputSourceEndBehavior,
    InputSourceType,
    InputState,
    InputTimecodeSource,
    InputType,
    LastFrameClippingBehavior,
    ListChannelsPaginatorName,
    ListInputDeviceTransfersPaginatorName,
    ListInputDevicesPaginatorName,
    ListInputSecurityGroupsPaginatorName,
    ListInputsPaginatorName,
    ListMultiplexProgramsPaginatorName,
    ListMultiplexesPaginatorName,
    ListOfferingsPaginatorName,
    ListReservationsPaginatorName,
    LogLevel,
    M2tsAbsentInputAudioBehavior,
    M2tsArib,
    M2tsAribCaptionsPidControl,
    M2tsAudioBufferModel,
    M2tsAudioInterval,
    M2tsAudioStreamType,
    M2tsBufferModel,
    M2tsCcDescriptor,
    M2tsEbifControl,
    M2tsEbpPlacement,
    M2tsEsRateInPes,
    M2tsKlv,
    M2tsNielsenId3Behavior,
    M2tsPcrControl,
    M2tsRateMode,
    M2tsScte35Control,
    M2tsSegmentationMarkers,
    M2tsSegmentationStyle,
    M2tsTimedMetadataBehavior,
    M3u8NielsenId3Behavior,
    M3u8PcrControl,
    M3u8Scte35Behavior,
    M3u8TimedMetadataBehavior,
    MotionGraphicsInsertion,
    Mp2CodingMode,
    Mpeg2AdaptiveQuantization,
    Mpeg2ColorMetadata,
    Mpeg2ColorSpace,
    Mpeg2DisplayRatio,
    Mpeg2GopSizeUnits,
    Mpeg2ScanType,
    Mpeg2SubGopLength,
    Mpeg2TimecodeInsertionBehavior,
    MsSmoothH265PackagingType,
    MultiplexCreatedWaiterName,
    MultiplexDeletedWaiterName,
    MultiplexRunningWaiterName,
    MultiplexState,
    MultiplexStoppedWaiterName,
    NetworkInputServerValidation,
    NielsenPcmToId3TaggingState,
    OfferingDurationUnits,
    OfferingType,
    PipelineId,
    PreferredChannelPipeline,
    ReservationCodec,
    ReservationMaximumBitrate,
    ReservationMaximumFramerate,
    ReservationResolution,
    ReservationResourceType,
    ReservationSpecialFeature,
    ReservationState,
    ReservationVideoQuality,
    RtmpAdMarkers,
    RtmpCacheFullBehavior,
    RtmpCaptionData,
    RtmpOutputCertificateMode,
    S3CannedAcl,
    Scte20Convert608To708,
    Scte35AposNoRegionalBlackoutBehavior,
    Scte35AposWebDeliveryAllowedBehavior,
    Scte35ArchiveAllowedFlag,
    Scte35DeviceRestrictions,
    Scte35NoRegionalBlackoutFlag,
    Scte35SegmentationCancelIndicator,
    Scte35SpliceInsertNoRegionalBlackoutBehavior,
    Scte35SpliceInsertWebDeliveryAllowedBehavior,
    Scte35WebDeliveryAllowedFlag,
    SmoothGroupAudioOnlyTimecodeControl,
    SmoothGroupCertificateMode,
    SmoothGroupEventIdMode,
    SmoothGroupEventStopBehavior,
    SmoothGroupSegmentationMode,
    SmoothGroupSparseTrackType,
    SmoothGroupStreamManifestBehavior,
    SmoothGroupTimestampOffsetMode,
    Smpte2038DataPreference,
    TemporalFilterPostFilterSharpening,
    TemporalFilterStrength,
    TimecodeConfigSource,
    TtmlDestinationStyleControl,
    UdpTimedMetadataId3Frame,
    VideoDescriptionRespondToAfd,
    VideoDescriptionScalingBehavior,
    VideoSelectorColorSpace,
    VideoSelectorColorSpaceUsage,
    WavCodingMode,
)

def check_value(value: AacCodingMode) -> bool:
    ...
```

### Typed dictionaries

`mypy_boto3_medialive.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_medialive.type_defs import (
    AacSettingsTypeDef,
    Ac3SettingsTypeDef,
    AncillarySourceSettingsTypeDef,
    ArchiveCdnSettingsTypeDef,
    ArchiveContainerSettingsTypeDef,
    ArchiveGroupSettingsTypeDef,
    ArchiveOutputSettingsTypeDef,
    ArchiveS3SettingsTypeDef,
    AudioChannelMappingTypeDef,
    AudioCodecSettingsTypeDef,
    AudioDescriptionTypeDef,
    AudioLanguageSelectionTypeDef,
    AudioNormalizationSettingsTypeDef,
    AudioOnlyHlsSettingsTypeDef,
    AudioPidSelectionTypeDef,
    AudioSelectorSettingsTypeDef,
    AudioSelectorTypeDef,
    AudioSilenceFailoverSettingsTypeDef,
    AudioTrackSelectionTypeDef,
    AudioTrackTypeDef,
    AutomaticInputFailoverSettingsTypeDef,
    AvailBlankingTypeDef,
    AvailConfigurationTypeDef,
    AvailSettingsTypeDef,
    BatchDeleteResponseTypeDef,
    BatchFailedResultModelTypeDef,
    BatchScheduleActionCreateRequestTypeDef,
    BatchScheduleActionCreateResultTypeDef,
    BatchScheduleActionDeleteRequestTypeDef,
    BatchScheduleActionDeleteResultTypeDef,
    BatchStartResponseTypeDef,
    BatchStopResponseTypeDef,
    BatchSuccessfulResultModelTypeDef,
    BatchUpdateScheduleResponseTypeDef,
    BlackoutSlateTypeDef,
    BurnInDestinationSettingsTypeDef,
    CaptionDescriptionTypeDef,
    CaptionDestinationSettingsTypeDef,
    CaptionLanguageMappingTypeDef,
    CaptionRectangleTypeDef,
    CaptionSelectorSettingsTypeDef,
    CaptionSelectorTypeDef,
    CdiInputSpecificationTypeDef,
    ChannelEgressEndpointTypeDef,
    ChannelSummaryTypeDef,
    ChannelTypeDef,
    CreateChannelResponseTypeDef,
    CreateInputResponseTypeDef,
    CreateInputSecurityGroupResponseTypeDef,
    CreateMultiplexProgramResponseTypeDef,
    CreateMultiplexResponseTypeDef,
    CreatePartnerInputResponseTypeDef,
    DeleteChannelResponseTypeDef,
    DeleteMultiplexProgramResponseTypeDef,
    DeleteMultiplexResponseTypeDef,
    DeleteReservationResponseTypeDef,
    DescribeChannelResponseTypeDef,
    DescribeInputDeviceResponseTypeDef,
    DescribeInputDeviceThumbnailResponseTypeDef,
    DescribeInputResponseTypeDef,
    DescribeInputSecurityGroupResponseTypeDef,
    DescribeMultiplexProgramResponseTypeDef,
    DescribeMultiplexResponseTypeDef,
    DescribeOfferingResponseTypeDef,
    DescribeReservationResponseTypeDef,
    DescribeScheduleResponseTypeDef,
    DvbNitSettingsTypeDef,
    DvbSdtSettingsTypeDef,
    DvbSubDestinationSettingsTypeDef,
    DvbSubSourceSettingsTypeDef,
    DvbTdtSettingsTypeDef,
    Eac3SettingsTypeDef,
    EbuTtDDestinationSettingsTypeDef,
    EmbeddedSourceSettingsTypeDef,
    EncoderSettingsTypeDef,
    FailoverConditionSettingsTypeDef,
    FailoverConditionTypeDef,
    FeatureActivationsTypeDef,
    FecOutputSettingsTypeDef,
    FixedModeScheduleActionStartSettingsTypeDef,
    Fmp4HlsSettingsTypeDef,
    FollowModeScheduleActionStartSettingsTypeDef,
    FrameCaptureCdnSettingsTypeDef,
    FrameCaptureGroupSettingsTypeDef,
    FrameCaptureOutputSettingsTypeDef,
    FrameCaptureS3SettingsTypeDef,
    FrameCaptureSettingsTypeDef,
    GlobalConfigurationTypeDef,
    H264ColorSpaceSettingsTypeDef,
    H264FilterSettingsTypeDef,
    H264SettingsTypeDef,
    H265ColorSpaceSettingsTypeDef,
    H265FilterSettingsTypeDef,
    H265SettingsTypeDef,
    Hdr10SettingsTypeDef,
    HlsAkamaiSettingsTypeDef,
    HlsBasicPutSettingsTypeDef,
    HlsCdnSettingsTypeDef,
    HlsGroupSettingsTypeDef,
    HlsId3SegmentTaggingScheduleActionSettingsTypeDef,
    HlsInputSettingsTypeDef,
    HlsMediaStoreSettingsTypeDef,
    HlsOutputSettingsTypeDef,
    HlsS3SettingsTypeDef,
    HlsSettingsTypeDef,
    HlsTimedMetadataScheduleActionSettingsTypeDef,
    HlsWebdavSettingsTypeDef,
    InputAttachmentTypeDef,
    InputChannelLevelTypeDef,
    InputClippingSettingsTypeDef,
    InputDestinationRequestTypeDef,
    InputDestinationTypeDef,
    InputDestinationVpcTypeDef,
    InputDeviceConfigurableSettingsTypeDef,
    InputDeviceHdSettingsTypeDef,
    InputDeviceNetworkSettingsTypeDef,
    InputDeviceRequestTypeDef,
    InputDeviceSettingsTypeDef,
    InputDeviceSummaryTypeDef,
    InputDeviceUhdSettingsTypeDef,
    InputLocationTypeDef,
    InputLossBehaviorTypeDef,
    InputLossFailoverSettingsTypeDef,
    InputPrepareScheduleActionSettingsTypeDef,
    InputSecurityGroupTypeDef,
    InputSettingsTypeDef,
    InputSourceRequestTypeDef,
    InputSourceTypeDef,
    InputSpecificationTypeDef,
    InputSwitchScheduleActionSettingsTypeDef,
    InputTypeDef,
    InputVpcRequestTypeDef,
    InputWhitelistRuleCidrTypeDef,
    InputWhitelistRuleTypeDef,
    KeyProviderSettingsTypeDef,
    ListChannelsResponseTypeDef,
    ListInputDeviceTransfersResponseTypeDef,
    ListInputDevicesResponseTypeDef,
    ListInputSecurityGroupsResponseTypeDef,
    ListInputsResponseTypeDef,
    ListMultiplexProgramsResponseTypeDef,
    ListMultiplexesResponseTypeDef,
    ListOfferingsResponseTypeDef,
    ListReservationsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    M2tsSettingsTypeDef,
    M3u8SettingsTypeDef,
    MediaConnectFlowRequestTypeDef,
    MediaConnectFlowTypeDef,
    MediaPackageGroupSettingsTypeDef,
    MediaPackageOutputDestinationSettingsTypeDef,
    MotionGraphicsActivateScheduleActionSettingsTypeDef,
    MotionGraphicsConfigurationTypeDef,
    MotionGraphicsSettingsTypeDef,
    Mp2SettingsTypeDef,
    Mpeg2FilterSettingsTypeDef,
    Mpeg2SettingsTypeDef,
    MsSmoothGroupSettingsTypeDef,
    MsSmoothOutputSettingsTypeDef,
    MultiplexMediaConnectOutputDestinationSettingsTypeDef,
    MultiplexOutputDestinationTypeDef,
    MultiplexOutputSettingsTypeDef,
    MultiplexProgramChannelDestinationSettingsTypeDef,
    MultiplexProgramPacketIdentifiersMapTypeDef,
    MultiplexProgramPipelineDetailTypeDef,
    MultiplexProgramServiceDescriptorTypeDef,
    MultiplexProgramSettingsTypeDef,
    MultiplexProgramSummaryTypeDef,
    MultiplexProgramTypeDef,
    MultiplexSettingsSummaryTypeDef,
    MultiplexSettingsTypeDef,
    MultiplexStatmuxVideoSettingsTypeDef,
    MultiplexSummaryTypeDef,
    MultiplexTypeDef,
    MultiplexVideoSettingsTypeDef,
    NetworkInputSettingsTypeDef,
    NielsenConfigurationTypeDef,
    OfferingTypeDef,
    OutputDestinationSettingsTypeDef,
    OutputDestinationTypeDef,
    OutputGroupSettingsTypeDef,
    OutputGroupTypeDef,
    OutputLocationRefTypeDef,
    OutputSettingsTypeDef,
    OutputTypeDef,
    PaginatorConfigTypeDef,
    PauseStateScheduleActionSettingsTypeDef,
    PipelineDetailTypeDef,
    PipelinePauseStateSettingsTypeDef,
    PurchaseOfferingResponseTypeDef,
    RemixSettingsTypeDef,
    ReservationResourceSpecificationTypeDef,
    ReservationTypeDef,
    ResponseMetadata,
    RtmpGroupSettingsTypeDef,
    RtmpOutputSettingsTypeDef,
    ScheduleActionSettingsTypeDef,
    ScheduleActionStartSettingsTypeDef,
    ScheduleActionTypeDef,
    Scte20SourceSettingsTypeDef,
    Scte27SourceSettingsTypeDef,
    Scte35DeliveryRestrictionsTypeDef,
    Scte35DescriptorSettingsTypeDef,
    Scte35DescriptorTypeDef,
    Scte35ReturnToNetworkScheduleActionSettingsTypeDef,
    Scte35SegmentationDescriptorTypeDef,
    Scte35SpliceInsertScheduleActionSettingsTypeDef,
    Scte35SpliceInsertTypeDef,
    Scte35TimeSignalAposTypeDef,
    Scte35TimeSignalScheduleActionSettingsTypeDef,
    StandardHlsSettingsTypeDef,
    StartChannelResponseTypeDef,
    StartMultiplexResponseTypeDef,
    StartTimecodeTypeDef,
    StaticImageActivateScheduleActionSettingsTypeDef,
    StaticImageDeactivateScheduleActionSettingsTypeDef,
    StaticKeySettingsTypeDef,
    StopChannelResponseTypeDef,
    StopMultiplexResponseTypeDef,
    StopTimecodeTypeDef,
    TeletextSourceSettingsTypeDef,
    TemporalFilterSettingsTypeDef,
    TimecodeConfigTypeDef,
    TransferringInputDeviceSummaryTypeDef,
    TtmlDestinationSettingsTypeDef,
    UdpContainerSettingsTypeDef,
    UdpGroupSettingsTypeDef,
    UdpOutputSettingsTypeDef,
    UpdateChannelClassResponseTypeDef,
    UpdateChannelResponseTypeDef,
    UpdateInputDeviceResponseTypeDef,
    UpdateInputResponseTypeDef,
    UpdateInputSecurityGroupResponseTypeDef,
    UpdateMultiplexProgramResponseTypeDef,
    UpdateMultiplexResponseTypeDef,
    UpdateReservationResponseTypeDef,
    VideoBlackFailoverSettingsTypeDef,
    VideoCodecSettingsTypeDef,
    VideoDescriptionTypeDef,
    VideoSelectorColorSpaceSettingsTypeDef,
    VideoSelectorPidTypeDef,
    VideoSelectorProgramIdTypeDef,
    VideoSelectorSettingsTypeDef,
    VideoSelectorTypeDef,
    VpcOutputSettingsDescriptionTypeDef,
    VpcOutputSettingsTypeDef,
    WaiterConfigTypeDef,
    WavSettingsTypeDef,
)

def get_structure() -> AacSettingsTypeDef:
    return {
      ...
    }
```
